searchopts library

Classes

Option<T extends Object>
SearchNextOptionIntent
An Intent to highlight the next option in the Search list.
SearchOptions<T extends Object>
SearchOptionsRenderConfig
SearchPreviousOptionIntent
An Intent to highlight the previous option in the autocomplete list.
SearchSelectOptionIntent
An Intent to select the current highlighted option in the Search list.